@@ -1,18 +1,18 @@
-from builtins import next
-import re
 import json
-from io import open, StringIO, BytesIO, TextIOWrapper
-from collections import OrderedDict
-import dateutil
-import requests
+import re
 import urllib
+from builtins import next
+from collections import OrderedDict
+from io import BytesIO, StringIO, TextIOWrapper, open
 
+import dateutil
 import pandas as pd
 import pyarrow.parquet as pq
+import requests
 from chardet.universaldetector import UniversalDetector
 
-from .filepath_or_buffer import FileOrBufferHandler
 from .. import dp_logging
+from .filepath_or_buffer import FileOrBufferHandler, is_stream_buffer
 
 logger = dp_logging.get_child_logger(__name__)
 
@@ -395,7 +395,7 @@ def detect_file_encoding(file_path, buffer_size=1024, max_lines=20):
     if not _decode_is_valid(encoding):
         try:
             from charset_normalizer import CharsetNormalizerMatches as CnM
-            
+
             # Try with small sample 
             with FileOrBufferHandler(file_path, 'rb') as input_file:
                 raw_data = input_file.read(10000)
@@ -605,21 +605,6 @@ def load_as_str_from_file(file_path, file_encoding=None, max_lines=10,
     return data_as_str
 
 
-def is_stream_buffer(filepath_or_buffer):
-    """
-    Determines whether a given argument is a filepath or buffer.
-
-    :param filepath_or_buffer: path to the file or buffer
-    :type filepath_or_buffer: str
-    :return: true if string is a buffer or false if string is a filepath
-    :rtype: boolean
-    """
-
-    if isinstance(filepath_or_buffer, (StringIO, BytesIO)):
-        return True
-    return False
-
-
 def is_valid_url(url_as_string):
     """
     Determines whether a given string is a valid URL
