@@ -1,13 +1,11 @@
-from __future__ import print_function
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function
 
 import os
 import unittest
-from io import StringIO, BytesIO
+from io import BytesIO, StringIO
 
-from dataprofiler.data_readers.data import Data, JSONData
 from dataprofiler.data_readers import json_data
-
+from dataprofiler.data_readers.data import Data, JSONData
 
 test_root_path = os.path.dirname(os.path.dirname(os.path.realpath(__file__)))
 
