@@ -1,9 +1,9 @@
 from unittest import mock
 
-from dataprofiler.profilers.profiler_options import DataLabelerOptions
-from dataprofiler.tests.profilers.profiler_options.test_base_inspector_options \
-     import TestBaseInspectorOptions
 from dataprofiler.labelers.base_data_labeler import BaseDataLabeler
+from dataprofiler.profilers.profiler_options import DataLabelerOptions
+from dataprofiler.tests.profilers.profiler_options.test_base_inspector_options import \
+    TestBaseInspectorOptions
 
 
 class TestDataLabelerOptions(TestBaseInspectorOptions):
