@@ -1,6 +1,6 @@
 from dataprofiler.profilers.profiler_options import ProfilerOptions
-from dataprofiler.tests.profilers.profiler_options.test_base_option \
-     import TestBaseOption
+from dataprofiler.tests.profilers.profiler_options.test_base_option import \
+    TestBaseOption
 
 
 class TestProfilerOptions(TestBaseOption):
